@@ -1,3 +1,6 @@
+import collections
+from copy import copy
+
 from visidata import *
 
 
@@ -29,7 +32,7 @@ def iterdispvals(sheet, *cols, format=False):
     for col in cols:
         transformers[col] = [ col.type ]
         if format:
-            formatMaker = getattr(col, 'format_'+(col.formatter or sheet.options.disp_formatter))
+            formatMaker = getattr(col, 'formatter_'+(col.formatter or sheet.options.disp_formatter))
             transformers[col].append(formatMaker(col._formatdict))
         trdict = sheet.safe_trdict()
         if trdict:
@@ -103,22 +106,20 @@ def save_cols(vd, cols):
 def saveSheets(vd, givenpath, *vsheets, confirm_overwrite=False):
     'Save all *vsheets* to *givenpath*.'
 
+    if not vsheets: # blank tuple
+        vd.warning('no sheets to save')
+        return
+
     filetype = givenpath.ext or options.save_filetype
 
     vd.clearCaches()
 
     savefunc = getattr(vsheets[0], 'save_' + filetype, None) or getattr(vd, 'save_' + filetype, None)
 
-    using_save_filetype = False
-
     if savefunc is None:
-        savefunc = getattr(vd, 'save_' + options.save_filetype, None) or vd.fail('no function to save as type %s, set options.save_filetype' % filetype)
-        vd.warning(f'save for {filetype} unavailable, using {options.save_filetype}')
-        using_save_filetype = True
+        vd.fail(f'no function to save as {filetype}')
 
-    if using_save_filetype and givenpath.exists() and confirm_overwrite:
-        vd.confirm("%s already exists. overwrite with %s? " % (givenpath.given, options.save_filetype))
-    elif givenpath.exists() and confirm_overwrite:
+    if givenpath.exists() and confirm_overwrite:
         vd.confirm("%s already exists. overwrite? " % givenpath.given)
 
     vd.status('saving %s sheets to %s as %s' % (len(vsheets), givenpath.given, filetype))
@@ -151,6 +152,23 @@ def saveSheets(vd, givenpath, *vsheets, confirm_overwrite=False):
     return vd.execAsync(_savefiles, vsheets, givenpath, savefunc, filetype)
 
 
+@VisiData.api
+def save_zip(vd, p, *vsheets):
+    vd.clearCaches()
+
+    import tempfile
+    import zipfile
+    with tempfile.TemporaryDirectory() as tmpdir:
+        with zipfile.ZipFile(str(p), 'w', zipfile.ZIP_DEFLATED, allowZip64=True, compresslevel=9) as zfp:
+            for vs in Progress(vsheets):
+                filetype = vs.options.save_filetype
+                tmpp = Path(f'{tmpdir}{vs.name}.{filetype}')
+                savefunc = getattr(vs, 'save_' + filetype, None) or getattr(vd, 'save_' + filetype, None)
+                savefunc(tmpp, vs)
+                zfp.write(tmpp, f'{vs.name}.{vs.options.save_filetype}')
+    vd.status('%s save finished' % p)
+
+
 @VisiData.api
 def save_txt(vd, p, *vsheets):
     with p.open_text(mode='w', encoding=vsheets[0].options.encoding) as fp:
